@@ -20,14 +20,18 @@
 #ifndef GDRIVESLAVE_H
 #define GDRIVESLAVE_H
 
+#include "pathcache.h"
+
 #include <KGAPI/Account>
 #include <KGAPI/Types>
 #include <KIO/SlaveBase>
 
-#include "accountmanager.h"
-#include "pathcache.h"
+#include <memory>
+
+class AbstractAccountManager;
 
 class QTemporaryFile;
+
 namespace KGAPI2
 {
 class Job;
@@ -61,6 +65,9 @@ public:
 
     virtual void mimetype(const QUrl &url) Q_DECL_OVERRIDE;
 
+protected:
+    void virtual_hook(int id, void *data) Q_DECL_OVERRIDE;
+
 private:
     Q_DISABLE_COPY(KIOGDrive)
 
@@ -70,6 +77,8 @@ private:
         PathIsFile = 2
     };
 
+    static KIO::UDSEntry accountToUDSEntry(const QString &accountName);
+
     void listAccounts();
     void createAccount();
 
@@ -78,11 +87,9 @@ private:
     Action handleError(const KGAPI2::Job &job, const QUrl &url);
     KIO::UDSEntry fileToUDSEntry(const KGAPI2::Drive::FilePtr &file, const QString &path) const;
 
+    void fileSystemFreeSpace(const QUrl &url);
 
-
-    KGAPI2::AccountPtr getAccount(const QString &accountName) {
-        return m_accountManager.account(accountName);
-    }
+    KGAPI2::AccountPtr getAccount(const QString &accountName);
 
     QString rootFolderId(const QString &accountId);
 
@@ -95,7 +102,7 @@ private:
      */
     bool runJob(KGAPI2::Job &job, const QUrl &url, const QString &accountId);
 
-    AccountManager m_accountManager;
+    std::unique_ptr<AbstractAccountManager> m_accountManager;
     PathCache m_cache;
 
     QMap<QString /* account */, QString /* rootId */> m_rootIds;
